#!/bin/sh
#------------------------------------------------- {COPYRIGHT-TOP-RM}
# Licensed Materials - Property of IBM                       
#                                                            
# "Restricted Materials of IBM"                              
#                                                            
# 5724-C51                                                   
#                                                            
# (C) Copyright IBM Corp. 2005 All Rights Reserved.
#                                                            
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with    
# IBM Corp.
#------------------------------------------------- {COPYRIGHT-END-RM}

# comlisten/src/bin/clproptec.ksh
# SID: 1.2
# Date Modified: 05/04/21 13:43:20


#
# Usage
#
function Usage
{
  print ""
  print " Usage:  sh clproptec"
}


# Retrieve installation path
INSTDIR=$(regfind -p "HKEY_LOCAL_MACHINE\SOFTWARE\Accessible Software, Inc.\Access1\1.0" -n "InstallDirectory" 2>nul: | grep InstallDirectory | sed 's/[ ]*InstallDirectory = //' | sed 's/\\/\\\\\\\\/g' | sed 's/\\\\\\\\$//g')

# Set Common Listener properties file path
CL_PROPERTIES_FILE="$INSTDIR/CommonListener/ASICommonListener.properties"

# Update Common Listener properties file
print "\nUpdating the TBSM Common Listener service properties file with the XML TEC Resources operational parameters..."

# Check to see if the properties file exists at the location derived from the registry
if [ -a "$CL_PROPERTIES_FILE" ]; then
  parmsflag=0
  appendflag=0
  
  # Check to see if the operational parameters exist in the properties file
  parmsflag=$(awk '
  BEGIN {
    enablefind = 0
    sleepfind = 0
    flagval = 0
    }

    /com.tivoli.tbsm.commonlistener.CL.enableTecXmlDiscovery/ { enablefind = 1   }
    /com.tivoli.tbsm.commonlistener.CL.sleepBetweenTecXmlPreprocess/ { sleepfind = 2 }

  END {
    flagval = flagval + enablefind + sleepfind;
    print flagval 
    }
  ' $CL_PROPERTIES_FILE)  

  # Debug 
  # echo "parmsflag: "$parmsflag

  if [ "$parmsflag" = 0 ]; then
    # Append to the properties file:  com.tivoli.tbsm.commonlistener.CL.enableTecXmlDiscovery
    print "\n\n# -----------------------------------------------------------------\n# Common Listener XML TEC Resource Discovery operational parameters\n# -----------------------------------------------------------------" >> "$CL_PROPERTIES_FILE"
    appendflag=1
  fi

  if [ "$parmsflag" != 1 -a "$parmsflag" != 3 ]; then
    # Append to the properties file:  com.tivoli.tbsm.commonlistener.CL.enableTecXmlDiscovery
    print "\n# Enable the preprocessing of TEC resource discovery data, previously received via\n# XML through the enqueuecl command, through the automatic invocation of SQL\n# procedure clpreprocessTecResources.\ncom.tivoli.tbsm.commonlistener.CL.enableTecXmlDiscovery=false" >> "$CL_PROPERTIES_FILE"
    appendflag=1
  fi

  if [ "$parmsflag" != 2 -a "$parmsflag" != 3 ]; then
    # Append to the properties file:  com.tivoli.tbsm.commonlistener.CL.sleepBetweenTecXmlPreprocess
    print "\n# Specifies how often SQL procedure cl_preprocessTecResources will be invoked to\n# preprocess TEC resource discovery data in the staging tables.  Specifying zero\n# will cause the stored procedure to be invoked as soon as a record becomes available.\n# The value is specified in seconds.\ncom.tivoli.tbsm.commonlistener.CL.sleepBetweenTecXmlPreprocess=10" >> "$CL_PROPERTIES_FILE"
    appendflag=1
  fi

  if [ "$appendflag" = 1 ]; then
    # Issue successful append message
    print "\nThe TBSM Common Listener service properties file was successfully updated.  The Common Listener service must be restarted for properties file changes to be enabled."
  else
    print "\nThe TBSM Common Listener service properties file already includes the XML TEC Resources operational parameters.  The properties file was not updated."
  fi
else
  # Issue error message
  print "\nERROR:  The TBSM Common Listener service properties file was not updated."
  print "File not found at expected location: $CL_PROPERTIES_FILE"
fi  

exit
